# BioinformaticAnalysisTools

## Introduction
A python command line toolkit for Bioinformatics and data science!

\<under development\>

- Author: Hua-nan ZHAO @Tsinghua University
- E-Mail: hermanzhaozzzz@gmail.com

## Installation
```shell
pip install --upgrade bioat
```


## usage
```shell
# list commands
bioat list
# check version
bioat version
# check information about bioat
bioat about

# example usage
bioat 
```

## history


## backup
```shell
 poetry add git+ssh://git@github.com:pysam-developers/pysam.git
```

